summaryrefslogtreecommitdiffstats
path: root/usr.sbin/sysinstall/installUpgrade.c
diff options
context:
space:
mode:
authorobrien <obrien@FreeBSD.org>2002-04-23 22:16:41 +0000
committerobrien <obrien@FreeBSD.org>2002-04-23 22:16:41 +0000
commitc8378615464233ebe8d09d2c58dbd40032d77e45 (patch)
tree3eee8dd61f995528c0a9e5d0ffb9521208186643 /usr.sbin/sysinstall/installUpgrade.c
parent3311fa2aba4cbec458dc454de77133714a47ccfa (diff)
downloadFreeBSD-src-c8378615464233ebe8d09d2c58dbd40032d77e45.zip
FreeBSD-src-c8378615464233ebe8d09d2c58dbd40032d77e45.tar.gz
Change the name of the 'bin' distribution to 'base'.
This is done since it contains much more than /bin, and also gets in the way when making a combined install+fixit CD. OK'ed by: jkh
Diffstat (limited to 'usr.sbin/sysinstall/installUpgrade.c')
-rw-r--r--usr.sbin/sysinstall/installUpgrade.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/usr.sbin/sysinstall/installUpgrade.c b/usr.sbin/sysinstall/installUpgrade.c
index 5b44b79..eccb50da 100644
--- a/usr.sbin/sysinstall/installUpgrade.c
+++ b/usr.sbin/sysinstall/installUpgrade.c
@@ -180,10 +180,10 @@ installUpgrade(dialogMenuItem *self)
if (!dmenuOpenSimple(&MenuDistributions, FALSE) || !Dists)
return DITEM_FAILURE;
}
- else if (!(Dists & DIST_BIN)) { /* No bin selected? Not much of an upgrade.. */
- if (msgYesNo("You didn't select the bin distribution as one of the distributons to load.\n"
+ else if (!(Dists & DIST_BASE)) { /* No base selected? Not much of an upgrade.. */
+ if (msgYesNo("You didn't select the base distribution as one of the distributons to load.\n"
"This one is pretty vital to a successful upgrade. Are you SURE you don't\n"
- "want to select the bin distribution? Chose No to bring up the Distributions\n"
+ "want to select the base distribution? Chose No to bring up the Distributions\n"
"menu again.") != 0) {
if (!dmenuOpenSimple(&MenuDistributions, FALSE))
return DITEM_FAILURE;
@@ -191,7 +191,7 @@ installUpgrade(dialogMenuItem *self)
}
/* Still?! OK! They must know what they're doing.. */
- if (!(Dists & DIST_BIN))
+ if (!(Dists & DIST_BASE))
extractingBin = FALSE;
if (RunningAsInit) {
@@ -325,20 +325,20 @@ media:
msgNotify("Beginning extraction of distributions..");
if (DITEM_STATUS(distExtractAll(self)) == DITEM_FAILURE) {
- msgConfirm("Hmmmm. We couldn't even extract the bin distribution. This upgrade\n"
+ msgConfirm("Hmmmm. We couldn't even extract the base distribution. This upgrade\n"
"should be considered a failure and started from the beginning, sorry!\n"
"The system will reboot now.");
dialog_clear();
systemShutdown(1);
}
else if (Dists) {
- if (!extractingBin || !(Dists & DIST_BIN)) {
+ if (!extractingBin || !(Dists & DIST_BASE)) {
msgNotify("The extraction process seems to have had some problems, but we got most\n"
"of the essentials. We'll treat this as a warning since it may have been\n"
"only non-essential distributions which failed to load.");
}
else {
- msgConfirm("Hmmmm. We couldn't even extract the bin distribution. This upgrade\n"
+ msgConfirm("Hmmmm. We couldn't even extract the base distribution. This upgrade\n"
"should be considered a failure and started from the beginning, sorry!\n"
"The system will reboot now.");
dialog_clear();
@@ -384,7 +384,7 @@ installUpgradeNonInteractive(dialogMenuItem *self)
variable_set2(SYSTEM_STATE, "upgrade", 0);
/* Make sure at least BIN is selected */
- Dists |= DIST_BIN;
+ Dists |= DIST_BASE;
if (RunningAsInit) {
Device **devs;
@@ -470,20 +470,20 @@ installUpgradeNonInteractive(dialogMenuItem *self)
msgNotify("Beginning extraction of distributions..");
if (DITEM_STATUS(distExtractAll(self)) == DITEM_FAILURE) {
- msgConfirm("Hmmmm. We couldn't even extract the bin distribution. This upgrade\n"
+ msgConfirm("Hmmmm. We couldn't even extract the base distribution. This upgrade\n"
"should be considered a failure and started from the beginning, sorry!\n"
"The system will reboot now.");
dialog_clear();
systemShutdown(1);
}
else if (Dists) {
- if (!(Dists & DIST_BIN)) {
+ if (!(Dists & DIST_BASE)) {
msgNotify("The extraction process seems to have had some problems, but we got most\n"
"of the essentials. We'll treat this as a warning since it may have been\n"
"only non-essential distributions which failed to upgrade.");
}
else {
- msgConfirm("Hmmmm. We couldn't even extract the bin distribution. This upgrade\n"
+ msgConfirm("Hmmmm. We couldn't even extract the base distribution. This upgrade\n"
"should be considered a failure and started from the beginning, sorry!\n"
"The system will reboot now.");
dialog_clear();
OpenPOWER on IntegriCloud